(devindex)=

# Development

## Contributing to `vak`

This is a community driven project and everyone is welcome to contribute.

The project is hosted at the
[vak GitHub repository](https://github.com/NickleDave/vak).

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**. Everyone must abide by our
[Code of Conduct](https://github.com/NickleDave/vak/blob/main/CODE_OF_CONDUCT.md)
and we encourage all to read it carefully.

```{toctree}
:maxdepth: 2

contributors
```

This development documentation is adapted from the exemplary guides provided by
[numpy](https://numpy.org), [pandas](https://pandas.pydata.org),
and [PyGMT](https://www.pygmt.org).
`vak` is built on `numpy` and `pandas` (among other libraries) ---
please cite them also if you use `vak` in your own work,
and consider contributing to their development.
